IdvLogLevel enum

Inheritance
Available extensions

Values

DEBUG → const IdvLogLevel
const IdvLogLevel(0)
INFO → const IdvLogLevel
const IdvLogLevel(1)
WARNING → const IdvLogLevel
const IdvLogLevel(2)
ERROR → const IdvLogLevel
const IdvLogLevel(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByValue(int? i) IdvLogLevel?

Constants

values → const List<IdvLogLevel>
A constant List of the values in this enum, in order of their declaration.